function [result, count] = cgpls(fnew, fold, error_old, hi, gi, gm, reg_matrixf, reg_matrixh, error_matrix)
% Performs a linesearch for positivity after the congugate gradient 
% minimization has been perfomed. The estimate of f is projected onto the 
% positivity constraint,
% fnew = fold, fold > 0
%           0,  fold < 0
% If the error due to the new f estimate is greater than the initial error, the 
% a new estimate for f is calculated:
% fest = fest + alpha * (fest - fold);
% This new value is projected and the error calculates.  If still greater than 
% the initial error alpha is halved and the process repeated until the new error 
% is less than or equal to the initial error.
% This is performed for the case where an energy constraint is imposed on f and h.
% Usage : [result] = cgplsb(fnew, fold, error_old, hi, gi, gm, reg_matrixf, reg_matrixh, error_matrix)       	
% Rachel Johnston, 21/9/98

% Is the correct version of cgpls.m - as it now incorporates the regularization
% of both f and h.

no_frames  = size(gi,3);
error_new = 1e37;
direction = fnew-fold;
alpha = 1;
count = 0;
while ((error_new > error_old)&(alpha > 1e-8))
	fnew = fold + alpha*(direction);
	fnew = fnew.*(fnew>0);
	error_new = cgerror(fnew, hi, gi, gm, reg_matrixf, error_matrix);
	reg_term  = zeros(1,1);
%	for i = 1:no_frames
%		reg_term = reg_term + sum(sum(reg_matrixh.*(hi(:,:,i).^2)));
%	end	
	error_new = error_new + reg_term*ones(1, size(error_new,2));
	alpha = alpha/2;
	count = count + 1;
end

result = fnew;		