function [T] = tmatrix(zenith, binary_sep, rsamples, hsamples, wavelength)

%  Generates the T matrix of covariances
%
% 
%  Inputs:  zenith	    - zenith angle        (degrees)
%	        binary_sep	- binary separation   (arcsecs)
%	        rsamples	- radius samples
%	        hsamples	- height samples	
%	        wavelength	- wavelength of light (m)
%  
%  Outputs: T		    - matrix of covariances
%
%  Usage:   [T] = tmatrix(0, 10, r, h, 589e-9);
%
%  R. A. Johnston, 14/1/99

% Preliminaries
secz = 1.0/cos(zenith*pi/180);
thi = binary_sep/(3600*180/pi);
dh = 2*hsamples(1);    
for j = 1 : max(size(hsamples))
   		%T(:,j) = 100*(scintcov(hsamples(j), wavelength, 1e-14, rsamples - thi*hsamples(j)*secz))';
   % covariance is computed with Cn2.dh=10^-14 m^1/3
	T(:,j) = scintcov(hsamples(j)*secz, wavelength, 1e-12, rsamples - thi*hsamples(j)*secz)';
end
